@@ -9,9 +9,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 973 2010-05-22 17:00:56Z pronovic $
+# Revision : $Id: release.py 1074 2014-10-03 17:55:34Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -33,8 +33,8 @@ Provides location to maintain version information.
 
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
-COPYRIGHT   = "2004-2010"
-VERSION     = "2.19.6"
-DATE        = "22 May 2010"
+COPYRIGHT   = "2004-2011,2013,2014"
+VERSION     = "2.23.3"
+DATE        = "03 Oct 2014"
 URL         = "http://cedar-backup.sourceforge.net/"
 
